<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="用户姓名" prop="userName">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入用户姓名"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="类型" prop="userName">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入用户姓名"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="身份证号" prop="idCard">
        <el-input
          v-model="queryParams.idCard"
          placeholder="请输入身份证号"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="单位名称" prop="dept">
        <el-input
          v-model="queryParams.dept"
          placeholder="请输入单位名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="操作类型">
        <el-cascader
          v-model="queryParams.operateTypeId"
          :options="typeList"
          :show-all-levels="false"
          :props="{ expandTrigger: 'hover', value: 'id',label: 'name',emitPath:false}"
          @change="handleChange"></el-cascader>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          size="mini"
          @click="openViolation({},'add')"
          v-hasPermi="['system:experts:add']"
        >新增处罚登记</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>
    <el-table v-loading="loading" :data="dataList">
      <el-table-column label="发生时间" align="center" prop="violationTime" />
      <el-table-column label="姓名" align="center" prop="name" />
      <el-table-column label="身份证号" align="center" prop="idCard">
        <template #default="scope">
          {{scope.row.idCard | peridcardtm}}
        </template>
      </el-table-column>
      <el-table-column label="IC卡编号" align="center" prop="icNum"/>
      <el-table-column label="电子证编号" align="center" prop="electNum"/>
      <el-table-column label="所属单位" align="center" prop="dept"/>
      <el-table-column label="作业种类" align="center" prop="jobCategory"/>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template #default="scope">

          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="open('核准')"
          >核准</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="open('撤销')"
          >撤销</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-view"
            @click="openViolation(scope.row,'view')"
          >查看详情</el-button>

          <el-button
            size="mini"
            type="text"
            style="color: red;"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:experts:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
    <violation-dialog ref="violationDialog" @getList="getList" :typeList="typeList"></violation-dialog>
  </div>
</template>

<script>

import violationDialog from "@/views/coalMine/cViolationRegistration/components/violationDialog.vue";
import {delViolation, getViolationPage} from "@/api/coalMine/violation";
import {getOperatePage} from "@/api/coalMine/operateType";
import {delPeople} from "@/api/coalMine/people";
export default {
  name: "cViolationRegistration",
  dicts: [],
  components: {
    violationDialog
  },
  data() {
    return {
      violationDialog: '',
      loading: false,
      showSearch: true,
      dataList: [],
      total: 0,
      typeList: [],
      queryParams: {
        name: '',
        idCard:'',
        dept: '',
        operateTypeId: null,
        isCm: 1,
        pageNum: 1,
        pageSize: 10
      },
    };
  },
  created() {
    this.getList()
    this.getTypeList()
  },
  methods: {
    async getList(){
      const t = this
      t.loading = true
      const res = await getViolationPage(t.queryParams)
      if(res.code == 200){
        t.dataList = res.rows
        t.total = res.total
      }else{
        t.$message({
          message: res.msg,
          type: 'warning'
        })
      }
      t.loading = false
    },
    async getTypeList() {
      this.loading = true;
      const res = await getOperatePage({name: ''})
      if(res.code == 200){
        this.typeList = this.handleTree(res.data, "id");
      }else{
        this.$message({
          type: 'warning',
          message: res.msg
        });
      }
      this.loading = false;
    },
    handleChange(){

    },
    open(val) {
            this.$confirm('确认'+val+'该项处罚?', '提示', {
              confirmButtonText: '确定',
              cancelButtonText: '取消',
              type: 'warning'
            }).then(() => {
              this.$message({
                type: 'success',
                message: val+'成功!'
              });
            }).catch(() => {
              this.$message({
                type: 'info',
                message: '已取消'+val
              });
            });
          },
    handleDelete(row){
      this.$confirm('此操作将永久删除该条数据, 是否继续?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(async () => {
        const res = await delViolation(row.violationId)
        if(res.code == 200){
          this.$message({
            type: 'success',
            message: '删除成功!'
          });
          await this.getList()
        }else{
          this.$message({
            type: 'warning',
            message: res.msg
          });
        }
      }).catch(() => {

      });
    },
    handleQuery(){
      this.queryParams.pageNum = 1
      this.getList()
    },
    resetQuery(){
      this.queryParams = {
        name: '',
        idCard:'',
        dept: '',
        operateTypeId: null,
        isCm: 1,
        pageNum: 1,
        pageSize: 10
      }
      this.getList()
    },
    openViolation(data,type){
      this.$refs.violationDialog.openDialog(data,type);
    }
  }
};
</script>
